==> haystack-0.6.1.tar.gz: test/io/Json_test.dart <==
///
/// Copyright (c) 2018, BAS Services & Graphics, LLC.
/// Licensed under the Academic Free License version 3.0
///

library haystack.json_test;

import 'package:haystack/core.dart';
import 'package:haystack/src/io/HJsonWriter.dart';
import 'package:test/test.dart';

import '../utils.dart';

void main() {
  group("Json", () {
    test("Writer", () {
      HGridBuilder gb = new HGridBuilder();
      gb.addCol("a");
      gb.addCol("b");
      gb.addRow( [ null, HBool.TRUE ] );
      gb.addRow( [ HMarker.VAL, null ] );
      gb.addRow( [ HRemove.VAL, HNA.VAL ]);
      gb.addRow( [ new HStr("test"), new HStr("with:colon") ]);
      gb.addRow( [ new HNum(12), new HNum(72.3, "\u00b0F") ]);
      gb.addRow( [ new HNum(double.negativeInfinity), new HNum(double.nan) ]);
      gb.addRow( [ new HDate(2015, 6, 9), new HTime(1, 2, 3) ] );
      gb.addRow( [ new HDateTime.fromMillis(1307377618069, new HTimeZone("New_York", tzOffset(-4, 0))),
        new HUri("foo.txt") ] );
      gb.addRow( [ new HRef("abc"), new HRef("abc", "A B C") ]);
      gb.addRow( [ new HBin("text/plain"), new HCoord(90, -123) ]);
      HGrid grid = gb.toGrid();

      String actual = HJsonWriter.gridToString(grid);

      List<String> lines = actual.split('\n');
      expect(lines[0], "{");
      expect(lines[1], "\"meta\": {\"ver\":\"2.0\"},");
      expect(lines[2], "\"cols\":[");
      expect(lines[3], "{\"name\":\"a\"},");
      expect(lines[4], "{\"name\":\"b\"}");
      expect(lines[5], "],");
      expect(lines[6], "\"rows\":[");
      expect(lines[7], "{\"b\":true},");
      expect(lines[8], "{\"a\":\"m:\"},");
      expect(lines[9], "{\"a\":\"x:\", \"b\":\"z:\"},");
      expect(lines[10], "{\"a\":\"test\", \"b\":\"s:with:colon\"},");
      expect(lines[11], "{\"a\":\"n:12\", \"b\":\"n:72.3 \u00b0F\"},");
      expect(lines[12], "{\"a\":\"n:-INF\", \"b\":\"n:NaN\"},");
      expect(lines[13], "{\"a\":\"d:2015-06-09\", \"b\":\"h:01:02:03\"},");
      expect(lines[14], "{\"a\":\"t:2011-06-06T12:26:58.069-04:00 New_York\", \"b\":\"u:foo.txt\"},");
      expect(lines[15], "{\"a\":\"r:abc\", \"b\":\"r:abc A B C\"},");
      expect(lines[16], "{\"a\":\"b:text/plain\", \"b\":\"c:90.0,-123.0\"}");
      expect(lines[17], "]");
      expect(lines[18], "}");
    });
  });
}

==> haystack-2.0.1.tar.gz: test/io/Json_test.dart <==
///
/// Copyright (c) 2018, BAS Services & Graphics, LLC.
/// Licensed under the Academic Free License version 3.0
///

library haystack.json_test;

import 'package:haystack/haystack.dart';
import 'package:haystack/src/io/HJsonWriter.dart';
import 'package:test/test.dart';

import '../utils.dart';

void main() {
  group("Json", () {
    test("Writer", () {
      HGridBuilder gb = HGridBuilder();
      gb.addCol("a");
      gb.addCol("b");
      gb.addRow( [ null, HBool.TRUE ] );
      gb.addRow( [ HMarker.VAL, null ] );
      gb.addRow( [ HRemove.VAL, HNA.VAL ]);
      gb.addRow( [ HStr("test"), HStr("with:colon") ]);
      gb.addRow( [ HNum(12), HNum(72.3, "\u00b0F") ]);
      gb.addRow( [ HNum(double.negativeInfinity), HNum(double.nan) ]);
      gb.addRow( [ HDate(2015, 6, 9), HTime(1, 2, 3) ] );
      gb.addRow( [ HDateTime.fromMillis(1307377618069, HTimeZone("New_York", tzOffset(-4, 0))),
        HUri("foo.txt") ] );
      gb.addRow( [ HRef("abc"), HRef("abc", "A B C") ]);
      gb.addRow( [ HBin("text/plain"), HCoord(90, -123) ]);
      HGrid grid = gb.toGrid();

      String actual = HJsonWriter.gridToString(grid);

      List<String> lines = actual.split('\n');
      expect(lines[0], "{");
      expect(lines[1], "\"meta\": {\"ver\":\"2.0\"},");
      expect(lines[2], "\"cols\":[");
      expect(lines[3], "{\"name\":\"a\"},");
      expect(lines[4], "{\"name\":\"b\"}");
      expect(lines[5], "],");
      expect(lines[6], "\"rows\":[");
      expect(lines[7], "{\"b\":true},");
      expect(lines[8], "{\"a\":\"m:\"},");
      expect(lines[9], "{\"a\":\"x:\", \"b\":\"z:\"},");
      expect(lines[10], "{\"a\":\"test\", \"b\":\"s:with:colon\"},");
      expect(lines[11], "{\"a\":\"n:12\", \"b\":\"n:72.3 \u00b0F\"},");
      expect(lines[12], "{\"a\":\"n:-INF\", \"b\":\"n:NaN\"},");
      expect(lines[13], "{\"a\":\"d:2015-06-09\", \"b\":\"h:01:02:03\"},");
      expect(lines[14], "{\"a\":\"t:2011-06-06T12:26:58.069-04:00 New_York\", \"b\":\"u:foo.txt\"},");
      expect(lines[15], "{\"a\":\"r:abc\", \"b\":\"r:abc A B C\"},");
      expect(lines[16], "{\"a\":\"b:text/plain\", \"b\":\"c:90.0,-123.0\"}");
      expect(lines[17], "]");
      expect(lines[18], "}");
    });
  });
}
